@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2015 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2015-2016 Mir Calculate. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -37,7 +37,7 @@ class ClBuilderPrepareAction(Action):
                     TemplatesError,
                     BuilderError, GitError)
 
-    successMessage = __("Build prepared successfully")
+    successMessage = __("Build prepared successfully in {cl_builder_path}")
     failedMessage = __("Preparing the build is failed")
     interruptMessage = __("Preparing manually interrupted")
 
